
/**
*  选择项
*/

import React, { forwardRef, useImperativeHandle, useState } from 'react';
import { Modal, TouchableOpacity } from 'react-native';
import Picker from 'react-native-picker';
import { FormProps } from '../../kit';

interface Props extends FormProps {

    /**
    *  标题
    */
    pickerTitleText?: string,

    /**
    *  数据源
    */
    pickerData?: any[],

    /**
    *  当前选中数据
    */
    selectedValue?: any,

    /**
    *  确认选择事件
    */
    onPickerConfirm?: (value: any[],) => void;

    /**
     *  取消选择事件
     */
    onPickerCancel?: (value: any[],) => void;

    /**
     *  选择中事件
     */
    onPickerSelect?: (value: any[],) => void;

}

export interface PickerHandle {
    showPicker: () => void,
    hiddenPicker: () => void
}

export default forwardRef<PickerHandle, Props>(function BmPicker(props, ref) {

    const [visible, setVisible] = useState(false)
    /**
     *  显示picker
     */
    let showPicker = () => {
        setVisible(true);
        // 如果有数据源 弹出pick选择器
        Picker.init({
            pickerTitleText: props.pickerTitleText || '选择',
            pickerCancelBtnText: '取消',
            pickerConfirmBtnText: '确认',
            pickerData: props.pickerData,
            selectedValue: props.selectedValue,
            pickerConfirmBtnColor: [90, 169, 250, 1],
            pickerCancelBtnColor: [153, 153, 153, 1],
            pickerTitleColor: [51, 51, 51, 1],
            pickerToolBarBg: [255, 255, 255, 1],
            pickerBg: [255, 255, 255, 1],
            onPickerConfirm: props.onPickerConfirm,
            onPickerCancel: props.onPickerCancel,
            onPickerSelect: props.onPickerSelect
        });
        Picker.show();
    }

    /**
     *  隐藏picker
     */
    let hiddenPicker = () => {
        setVisible(false)
        Picker.hide()
    }

    useImperativeHandle(ref, () => ({ showPicker, hiddenPicker }))


    return (
        <Modal visible={visible}
            transparent={true}
            animationType='none'
            onRequestClose={hiddenPicker}>
            <TouchableOpacity style={{ flex: 1, backgroundColor: '#99999999' }} onPress={hiddenPicker} />
        </Modal >
    )

})
